@@ -116,9 +116,11 @@ QStringList &KOrganizerEditorConfig::templates(KCalCore::IncidenceBase::Incidenc
     if (type == KCalCore::IncidenceBase::TypeEvent) {
         //TODO remove mEventTemplates+etc from Prefs::instance()
         return CalendarSupport::KCalPrefs::instance()->mEventTemplates;
-    } if (type == KCalCore::IncidenceBase::TypeTodo) {
+    }
+    if (type == KCalCore::IncidenceBase::TypeTodo) {
         return CalendarSupport::KCalPrefs::instance()->mTodoTemplates;
-    } if (type == KCalCore::IncidenceBase::TypeJournal) {
+    }
+    if (type == KCalCore::IncidenceBase::TypeJournal) {
         return CalendarSupport::KCalPrefs::instance()->mJournalTemplates;
     }
     return EditorConfig::templates(type);
